<?php
// $Id$

/**
 * @file
 * ANU box block.
 *
 * Implements ANU box styles for blocks.
 */

/**
 * Implementation of hook_preprocess_block().
 * Introduces ANU style settings to the block template.
 */
function anu_content_styles_preprocess_block(&$vars) {
  // Fetch settings
  $block = $vars['block'];
  if (!empty($block->module) && !empty($block->delta)) {
    // Fetch settings
    $module_id = array($block->module => $block->delta);
    $settings = anu_content_styles_get('block', $module_id);

    if (!empty($settings) && $settings['use_anu_styles']) {
      // Set ANU styles information
      $vars['anu_content_styles']['show_box_header'] = $settings['box']['show_title'] == 'header';
      $styles = array(
        $settings['box']['style'],
        $settings['border']['style'],
        $settings['border']['color'],
        $settings['content']['bg'],
        $settings['content']['fg'],
      );
      $vars['anu_content_styles']['styles'] = array_filter($styles, '_not_empty');
    }
  }
}

/********************************
 * Form overrides.
 ********************************/

/**
 * Implementation of hook_form_alter().
 * Add configuration form to new block page.
 */
function anu_content_styles_form_block_add_block_form_alter(&$form, &$form_state) {
  _anu_content_styles_block_insert_form($form, $form_state);
}

/**
 * Implementation of hook_form_alter().
 * Add configuration form to block edit page.
 */
function anu_content_styles_form_block_admin_configure_alter(&$form, &$form_state) {
  _anu_content_styles_block_insert_form($form, $form_state);
}

/**
 * Internal use only.
 * Inserts the form into existing block form.
 */
function _anu_content_styles_block_insert_form(&$form, &$form_state) {
  // Put the main block editing fieldset at the top
  $form['block_settings']['#weight'] = -20;
  // Make new fieldset
  $form['anu_content_styles'] = array(
    '#type' => 'fieldset',
    '#title' => t('ANU styles'),
    '#tree' => TRUE,
    '#weight' => -1,
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['anu_content_styles']['use_anu_styles'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display this block using ANU styles'),
    '#description' => t('If this option is deselected, none of the following settings will be saved.'),
    '#weight' => -10,
  );

  // Fetch settings
  $settings = _anu_content_styles_block_fetch_settings($form['module']['#value'], $form['delta']['#value']);
  
  // Override settings with form state
  if (!empty($form_state['values']['anu_content_styles'])) {
    $settings = $form_state['values']['anu_content_styles'];
  }

  if (!empty($settings)) {
    // Check the box above and expand the fieldset
    $form['anu_content_styles']['use_anu_styles']['#default_value'] = TRUE;
    $form['anu_content_styles']['#collapsed'] = FALSE;
    // Override settings from form state if any
    $values = $form_state['values']['anu_content_styles'];

  }
  // Get form and push
  $form['anu_content_styles'] += anu_content_styles_config_form($settings);

  // Set validate and submit functions
  $form['#validate'][] = 'anu_content_styles_config_form_validate';
  $form['#submit'][] = 'anu_content_styles_form_block_submit';
}

/**
 * Form submit callback.
 * Saves settings for this block
 */
function anu_content_styles_form_block_submit(&$form, &$form_state) {
  $values = $form_state['values'];
  if (!empty($values['anu_content_styles'])) {
    // Get identifiers
    $module_id = array($values['module'] => $values['delta']);
    // Fetch settings-related variables
    $settings = $values['anu_content_styles'];
    // Update values
    anu_content_styles_set('block', $module_id, $settings);
  }
}

/**
 * Internal use only.
 * Fetch settings.
 */
function _anu_content_styles_block_fetch_settings($module, $delta) {
  if ($settings = anu_content_styles_get('block', array($module => $delta))) {
    // Fetch settings
    return $settings;
  } else {
    // Not found
    return array();
  }
}
